#!/bin/bash


### TODO: 
### * keep track of errors
### * NULL file compression
### * notification when tile completes
### * time spent


# horizon angle step size
# this is used in several places
step=30

# tile code, from tileindex vector map | attribute table
# note: "-" has been replaced by "_"
tile=$1

# convert to format used by elevation, slope, aspect files
tile_original=`echo $tile | sed 's/_/-/g'`

# input files
elev="ele30_int_tiles-$tile_original"
asp="aspect30_tiles-$tile_original"
slope="slope30_tiles-$tile_original"

# output files: use "_" version of tile ID
# r.sun.daily invokes r.mapcalc which doesn't like "-" in filenames
beam="beam_tile_${tile}"

# set region focus to current tile
g.region -a rast=$elev

# ~ 13 minutes / tile
# make horizon maps in parallel
# files are recycled between runs
# hzangle_xxx
# arguments:
# 1: start angle
# 2: angle step
# 3: elevation tile
echo "creating horizon maps"
seq 0 $step 330 | parallel --gnu --progress "bash make-hz-maps.sh {} $step $elev"

## 
## r.sun.daily add-on
## TODO: this will periodically fail, with raster corruption issues
##       it is not clear what is causing the problems, because subsequent attemps succeed
##       given the long run time, it might be safer to implement this via custom code that
##       doesn't delete temporary files on error
##
# r.sun.daily --overwrite elevation=$elev aspect=$asp slope=$slope \
# start_day=1 end_day=365 beam_rad=$beam horizon_basename=hzangle horizon_step=$step nprocs=8



## manual approach to parallel r.sun
## maps recycled, FCELL, with units of MJ/sq.m
## named as "beam.001" ... "beam.365"
echo "creating daily beam radiance maps"
seq 1 365 | parallel --gnu --progress "bash daily-rad.sh {} $elev $asp $slope $step"

# sum maps over year
echo "creating annual sum"
daily_maps=$(g.list type=rast pattern="beam.*" separator=",")
r.series --o in="$daily_maps" out=$beam method=sum

## cleanup
# daily maps
g.remove --q -f type=rast name="$daily_maps"

# hz angle maps
hz_maps=$(g.list type=rast pattern="hzangle*" separator=",")
g.remove --q -f type=rast name="$hz_maps"


# done


