#!/bin/bash
# D.E. Beaudette
# compute beam radiance for a given set of input maps, horizon maps, step size, and DOY


## 2018-01-05: after switching to LZ4 compression, there have been no errors decompressing raster maps


# julian day
day=$1
day_fmt=`echo $day | awk '{printf("%.03d", $1)}'`

# input maps
elev=$2
asp=$3
slope=$4

# horizon angle step size
step=$5

# remove any maps that might be lying around from last time
# redirecting warnings (files not present) to dev/null
g.remove --q -f type=rast name=temp_beam_$day 2>/dev/null 
g.remove --q -f type=rast name=beam.$day_fmt 2>/dev/null 

# compute daily beam radiance
r.sun --quiet --overwrite elevation=$elev aspect=$asp slope=$slope \
day=$day horizon_basename=hzangle horizon_step=$step \
beam_rad=temp_beam_$day

# convert to MJ / sq. m
r.mapcalc --o "beam.$day_fmt = temp_beam_$day * (3600.0 / 100000.0)"

# clean-up
g.remove --q -f type=rast name=temp_beam_$day


